@@ -1,6 +1,6 @@
 #!/bin/sh
 # next line is a comment in tcl \
-exec wish "$0" ${1+"$@"}
+exec /usr/local/bin/wish8.6 "$0" ${1+"$@"}
 
 package require Tcldot
 
@@ -20,7 +20,7 @@ proc mouse_anyenter {c} {
 	set item [string range [lindex [$c gettags current] 0] 1 end]
 	set saveFill [list $item [lindex [$c itemconfigure 1$item -fill] 4]]
 	$c itemconfigure 1$item -fill black \
-		-stipple @$tk_library/demos/images/gray25.xbm
+		-stipple @/usr/local/share/examples/tk${MODTCL_VERSION}/images/gray25.xbm
 }
 
 # as the mouse moves out of an object restore its shading
@@ -30,7 +30,7 @@ proc mouse_anyleave {c} {
 		-fill [lindex $saveFill 1] -stipple {}
 }
 
-# if b1 is pressed over the brackground then start a node,
+# if b1 is pressed over the background then start a node,
 # if b1 is pressed over a node then start an edge
 proc mouse_b1_press {c x y} {
 	global startObj graphtype
@@ -481,7 +481,7 @@ proc zoom {c fact} {
         set data(idle) [after idle "zoomupdate $c"]
 }
 
-# update all text strings after zom operation is complete
+# update all text strings after zoom operation is complete
 proc zoomupdate {c} {
         upvar #0 $c data
         # adjust fonts
@@ -613,7 +613,7 @@ button .b.layout \
 	-height [.b.h cget -width] \
 	-foreground green \
 	-activeforeground green\
-	-bitmap @$tk_library/demos/images/gray25.xbm \
+	-bitmap @/usr/local/share/examples/tk${MODTCL_VERSION}/images/gray25.xbm \
 	-command "layout $c"
 
 # initialize zoom state
